==> chromium_99.0.4844.74.orig.tar.xz: chromium-99.0.4844.74/ash/webui/common/backend/plural_string_handler.cc <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ash/webui/common/backend/plural_string_handler.h"

#include "base/check.h"
#include "base/containers/contains.h"
#include "base/logging.h"
#include "base/values.h"
#include "chromeos/strings/grit/chromeos_strings.h"
#include "ui/base/l10n/l10n_util.h"

namespace ash {

PluralStringHandler::PluralStringHandler() = default;
PluralStringHandler::~PluralStringHandler() = default;

void PluralStringHandler::RegisterMessages() {
  web_ui()->RegisterDeprecatedMessageCallback(
      "getPluralString",
      base::BindRepeating(&PluralStringHandler::HandleGetPluralString,
                          base::Unretained(this)));
}

void PluralStringHandler::AddStringToPluralMap(const std::string& name,
                                               int string_id) {
  DCHECK(!base::Contains(string_id_map_, name));
  string_id_map_[name] = string_id;
}

void PluralStringHandler::HandleGetPluralString(const base::ListValue* args) {
  AllowJavascript();
  CHECK_EQ(3U, args->GetList().size());
  const std::string callback = args->GetList()[0].GetString();
  const std::string name = args->GetList()[1].GetString();
  const int count = args->GetList()[2].GetInt();
  DCHECK(base::Contains(string_id_map_, name));
  const std::u16string localized_string =
      l10n_util::GetPluralStringFUTF16(string_id_map_.at(name), count);
  ResolveJavascriptCallback(base::Value(callback),
                            base::Value(localized_string));
}

void PluralStringHandler::SetWebUIForTest(content::WebUI* web_ui) {
  DCHECK(web_ui);
  set_web_ui(web_ui);
}

}  // namespace ash

==> chromium_102.0.5005.61.orig.tar.xz: chromium-102.0.5005.61/ash/webui/common/backend/plural_string_handler.cc <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ash/webui/common/backend/plural_string_handler.h"

#include "base/check.h"
#include "base/containers/contains.h"
#include "base/logging.h"
#include "base/values.h"
#include "chromeos/strings/grit/chromeos_strings.h"
#include "ui/base/l10n/l10n_util.h"

namespace ash {

PluralStringHandler::PluralStringHandler() = default;
PluralStringHandler::~PluralStringHandler() = default;

void PluralStringHandler::RegisterMessages() {
  web_ui()->RegisterDeprecatedMessageCallback(
      "getPluralString",
      base::BindRepeating(&PluralStringHandler::HandleGetPluralString,
                          base::Unretained(this)));
}

void PluralStringHandler::AddStringToPluralMap(const std::string& name,
                                               int string_id) {
  DCHECK(!base::Contains(string_id_map_, name));
  string_id_map_[name] = string_id;
}

void PluralStringHandler::HandleGetPluralString(const base::ListValue* args) {
  AllowJavascript();
  CHECK_EQ(3U, args->GetListDeprecated().size());
  const std::string callback = args->GetListDeprecated()[0].GetString();
  const std::string name = args->GetListDeprecated()[1].GetString();
  const int count = args->GetListDeprecated()[2].GetInt();
  DCHECK(base::Contains(string_id_map_, name));
  const std::u16string localized_string =
      l10n_util::GetPluralStringFUTF16(string_id_map_.at(name), count);
  ResolveJavascriptCallback(base::Value(callback),
                            base::Value(localized_string));
}

void PluralStringHandler::SetWebUIForTest(content::WebUI* web_ui) {
  DCHECK(web_ui);
  set_web_ui(web_ui);
}

}  // namespace ash
